@@ -203,7 +203,7 @@ int SmsSender::exec()
                 parts++;
             consoleOutput("WARNING: SMS exceding 160 characters");
             consoleOutput(QString("         Splitted in %1 parts").arg(parts));
-            for (int i=0; i<parts - 1; i++)
+            for (int i=0; i<parts; i++)
                 messageBlocks.append(message.mid(160*i, 160));
         }
 
@@ -215,18 +215,25 @@ int SmsSender::exec()
         bool sent;
         int totalMsg = numbers.count() * messageBlocks.count();
         int i = 0;
+        bool msgSent = true;
         foreach(QString number, numbers){
-            i++;
-            consoleOutput(QString("[%1/%2]").arg(i).arg(totalMsg), false);
             foreach (QString msg, messageBlocks){
+                i++;
+                consoleOutput(QString("[%1/%2]").arg(i).arg(totalMsg), false);
                 if (m_Compose)
                     sent = compose(number, msg);
                 else
                     sent = send(number, msg);
 
+                msgSent = sent;
                 if (!sent)
                     res = errSmsFailed;
             }
+            //Save the full message in the sent folders
+            if (msgSent && !m_Compose && m_Save){
+                if (!saveMsgToSentFolder(number, messageBlocks.join("")))
+                    consoleOutput("WARNING: Failed to save sent sms");
+            }
         }
     }
 
@@ -324,10 +331,10 @@ bool SmsSender::send(QString number, QString messageText)
             consoleOutput("FAILED");
         }else{
             consoleOutput("OK");
-            if (m_Save){
+            /*if (m_Save){
                 if (!saveMsgToSentFolder(number, messageText))
                     consoleOutput("WARNING: Failed to save sent sms");
-            }
+            }*/
         }
     }
     delete pty;
