@@ -21,7 +21,9 @@
 #include <QCoreApplication>
 #include <QStringList>
 #include <QFile>
-#include <QSqlDatabase>
+#include <glib-2.0/glib.h>
+#include <rtcom-eventlogger/eventlogger.h>
+#include <rtcom-eventlogger/event.h>
 #include "ptyi.h"
 
 #define COMMAND_TIMEOUT 500
@@ -43,6 +45,8 @@ private:
         argLog,
         argDontSave,
         argFlash,
+        argDeliveryReport,
+        argValidity,
     };
 
     enum errors{
@@ -52,13 +56,15 @@ private:
         errLogfileOpenFailed = -3,
     };
 
-    QSqlDatabase* m_Db;
+    RTComEl* m_El;
     int m_Argc;
     QStringList m_Argv;
     bool m_Compose;
     bool m_Send;
     bool m_Save;
     bool m_Flash;
+    //bool m_DeliveryReport;
+    int m_Validity;
     QFile* m_LogFile;
 
     void consoleOutput(QString output, bool newline=true);
